#[non_exhaustive]pub enum Document {
WebPage(ArchivedPage),
}Expand description
Types of documents that can be stored in the flora archive.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WebPage(ArchivedPage)
A web page (typically HTML).
Implementations
Sourceimpl Document
impl Document
Sourcepub fn new_web_page_unchecked(data: Vec<u8>) -> Self
pub fn new_web_page_unchecked(data: Vec<u8>) -> Self
Creates a Document variant for a web page (HTML).
Does not check that the given data is actually HTML.
Sourcepub fn into_web_page(self) -> Option<Vec<u8>>
pub fn into_web_page(self) -> Option<Vec<u8>>
Returns the HTML data if the document is an HTML or text web page.
If it’s not a web page, returns None.