ClientDateTimeRecord

Enum ClientDateTimeRecord 

pub enum ClientDateTimeRecord {
    Parsed(DateTime<FixedOffset>),
    Interpolated {
        value: DateTime<FixedOffset>,
        raw: String,
    },
}
A Record to store the local date/time, as provided by a flora client.

Variants



Parsed(DateTime<FixedOffset>)

The naive date/time (without any time zone information).



Interpolated

The local time of the flora instance, if we couldn’t parse the one given by the client.

Fields

value: DateTime<FixedOffset>

The interpolated date time value.

raw: String

The original string, as given by the client.

Implementations

Source

impl ClientDateTimeRecord

pub fn new(local_datetime_client: &str) -> Self

Creates a new instance of DateTimeRecord from the given RFC 3339 local time string. Note: If we get an error trying to parse the string, we will use the current local time.

pub fn year(&self) -> i32

Retrieve the year component of the date/time value, regardless of whether we originally successfully parsed this from the date/time data submitted by the client, or interpolated it on the server.