LanguageRecord

Enum LanguageRecord 

pub enum LanguageRecord {
    Parsed(LanguageTag<String>),
    Raw {
        value: String,
        error_msg: String,
    },
}
Enum to encode the possible outcomes of parsing a language tag.

Variants



Parsed(LanguageTag<String>)

Variant containing a successfully parsed language tag.



Raw

Variant containing the raw value of the language tag if parsing failed.

Fields

value: String

The original raw value for the language tag, as given by the client.

error_msg: String

The error message from the parsing code.

Implementations

Source

impl LanguageRecord

pub fn new(language_tag: String) -> Self

Constructs a new LanguageRecord, regardless of whether oxilangtag parsed it successfully.

pub fn primary(&self) -> Result<String, RecordDataError>

Returns the primary language subtag, as extracted by oxilangtag.

See oxilangtag::LanguageTag::primary_language

Errors

If oxilangtag cannot parse the original record’s language tag, the error value will be the original record’s language tag as it was specified in the record (or None if the record didn’t have one).