pub struct RecordMeta {
pub id: i64,
pub url: String,
pub title: String,
pub client_datetime: ClientDateTimeRecord,
pub timestamp_flora: i64,
pub language: Option<LanguageRecord>,
pub updated_at: Option<i64>,
}Expand description
A Record’s metadata.
Includes all fields except the content.
Fields
id: i64SQLite ID.
url: StringOriginal URL from which the client got this record.
title: StringTitle for this record (may not match the web page title, if any).
client_datetime: ClientDateTimeRecordLocal date/time.
timestamp_flora: i64Unix timestamp from the Omry server when the record was first added.
language: Option<LanguageRecord>The record’s language (if any was specified).
updated_at: Option<i64>Unix timestamp from the server, present if the record was updated.