pub enum LanguageRecord {
Parsed(LanguageTag<String>),
Raw {
value: String,
error_msg: String,
},
}Expand description
Enum to encode the possible outcomes of parsing a language tag.
Variants
Parsed(LanguageTag<String>)
Variant containing a successfully parsed language tag.
Raw
Variant containing the raw value of the language tag if parsing failed.
Implementations
Sourceimpl LanguageRecord
impl LanguageRecord
Sourcepub fn new(language_tag: String) -> Self
pub fn new(language_tag: String) -> Self
Constructs a new LanguageRecord, regardless of whether oxilangtag parsed
it successfully.
Sourcepub fn primary(&self) -> Result<String, RecordDataError>
pub fn primary(&self) -> Result<String, RecordDataError>
Returns the primary language subtag,
as extracted by oxilangtag.
See oxilangtag::LanguageTag::primary_language
Errors
If oxilangtag cannot parse the original record’s language tag, the error value will be the original record’s language tag as it was specified in the record (or None if the record didn’t have one).